==> proc-10.1.59.tar.gz: proc/README.md <==
CONTENTS OF THIS FILE
---------------------

* Introduction

* Usage on standalone mode

* Usage on field mode

* Configuration

* Installation

* Future roadmap

* Learn more about Protected Content

* Similar project

* Maintainers

INTRODUCTION
------------
The aim of Protected Content (proc) module is enabling client side encryption
and decryption of content. It allows for two modes of usage. Standalone mode
and field mode. In standalone mode, the module provides forms to encrypt and
decrypt content. In field mode, the module provides a field type to
encrypt and decrypt text of files from within any fieldable form.

USAGE ON STANDALONE MODE
------------------------

* Access proc/generate-keys to generate keys for the current user.

* Access proc/add/&lt;uids_csv&gt; to encrypt a file for the users identified
  in &lt;uids_csv&gt; (a comma separated values list of user IDs). Protect
  Content will provide an Exclusive Access Link for the recipients to decrypt
  the file.

USAGE ON FIELD MODE
-------------------

* Add a field of type Proc Entity Reference Field to any form and configure it
accordingly to your needs.

GLOBAL CONFIGURATION
--------------------
Global configuration is available at /admin/config/system/proc.
Global settings available:

* Global stream wrapper: The stream wrapper to be used for the encrypted files.
  Defaults to "private".
* Enable stream wrapper globaly: If enabled, the global stream wrapper will be
  used for all encrypted files. If disabled, the database will be used for
  encrypted files.
* RSA keys size: The size of the RSA keys to be generated. Defaults to 2048.
* Maximum size for encryption in bytes: The maximum size of the files to be
  encrypted. Defaults to 10485760 (10MB).
* Block size (lines of armored cipher text): The block size for the armored
  cipher text. If left empty, the cipher text will not be split in blocks.
* Enable block size limit: If enabled, the block size limit will be enforced.
  If disabled, the block size limit will be ignored.
* Label for the encrypt link: The label for the encrypt link.
* Class for the encrypt link: The class for the encrypt link.

INSTALLATION
------------
Install as usual. OpenPGP.js v5.0.1 will be downloaded automatically form its
CDN.

OPENPGP.JS
----------
There is a copy of minified openpgp.js in the module, at js/openpgp.min.js. It
is used to encrypt and decrypt content. The version of openpgp.js is 5.0.1. The
library is licensed under the LGPL-3.0. Source code available at
https://openpgpjs.org/. The minified version is available at
https://unpkg.com/openpgp@5.0.1/dist/openpgp.min.js.

FUTURE ROADMAP
--------------
Text area field encryption and decryption.

Cryptographic signature and signature verification.

Multiple signatures per content with recursive encryption.

LEARN MORE ABOUT PROTECTED CONTENT
----------------------------------

[Protected Content, Secure open source day - Haarlem (2019)](https://youtu.be/rVWrkZPGj3s "Protected Content, Secure open source day - Haarlem (2019)")

[Protected Content: end-to-end PGP encryption for Drupal, Drupal Camp - Kyiv (2019)](https://youtu.be/Gx8uxEpi4Po " end-to-end PGP encryption for Drupal, Drupal Camp - Kyiv (2019)")

[Protected Content by Asymmetrical Client Side Encryption, Drupal Dev Days - Ghent (2022)](https://drupalcamp.be/en/drupal-dev-days-2020/session/protected-content-asymmetrical-client-side-encryption "Protected Content by Asymmetrical Client Side Encryption, Drupal Dev Days - Ghent (2022)")

[A pretty good content protection (Workshop), Drupal Con - Prague (2022)](https://events.drupal.org/prague2022/sessions/pretty-good-content-protection-workshop "A pretty good content protection (Workshop), Drupal Con - Prague (2022)")

SIMILAR PROJECT
---------------

[Client-Side File Crypto](https://www.drupal.org/project/client_side_file_crypto "Client-Side File Crypto")

MAINTAINERS
-----------
Rodrigo Panchiniak Fernandes - https://www.drupal.org/user/411448

Duarte Briz (duartebriz) - https://www.drupal.org/u/duartebriz

Reva Gomes (revagomes) - https://www.drupal.org/u/revagomes

==> proc-10.1.68.tar.gz: proc/README.md <==
CONTENTS OF THIS FILE
---------------------

* Introduction

* Usage on standalone mode

* Usage on field mode

* Global Configuration

* Widget Configuration

* Installation

* Future roadmap

* Learn more about Protected Content

* Similar project

* Maintainers

INTRODUCTION
------------
The aim of Protected Content (proc) module is enabling client side encryption
and decryption of content. It allows for two modes of usage: standalone mode
and field mode. In standalone mode, the module provides forms to encrypt and
decrypt content. In field mode, the module provides a field type to
encrypt and decrypt text or files from within any fieldable form.

USAGE ON STANDALONE MODE
------------------------

* Access proc/generate-keys to generate keys for the current user.

* Access proc/add/&lt;uids_csv&gt; to encrypt a file for the users identified
  in &lt;uids_csv&gt; (a comma separated values list of user IDs). Protect
  Content will provide an Exclusive Access Link for the recipients to decrypt
  the file.

USAGE ON FIELD MODE
-------------------

* Add a field of type Proc Entity Reference Field to any form and configure it
accordingly to your needs.

GLOBAL CONFIGURATION
--------------------
A global configuration form is available at /admin/config/system/proc.
Global settings available:

* Global stream wrapper
* Enable stream wrapper globally
* RSA keys size
* Maximum size for encryption in bytes
* Block size (lines of armored cipher text)
* Enable block size limit
* Global standard label for the encrypt link
* Global label for encryption on a file field when there is a default value
* Classes for the encrypt link
* Enable local password cache for fields
* Encryption strategy
* Suppress decrypt link from encryption success message
* Suppress entire encryption success message

WIDGET CONFIGURATION
--------------------
Widget configurations will be available when managing the form display of an
entity where the Proc Entity Reference Field is used. The following specific
settings are available:

* Machine name of the field containing the user IDs of recipients
* Machine name of the field containing user IDs of CC recipients
* Define the user IDs of recipients in a CSV list
* Endpoint for fetching user IDs of recipients
* Identifier of form elements to be used as parameters for the endpoint
* Label for the encrypt link
* Label for the decrypt link
* Type of identifier
* Modes of operation
* Modes of input
* Modes of decryption
* Password caching
* Trigger format
* Submit element ID for the master field
* Trigger decryption of another encrypted field
* Relabelling pattern

INSTALLATION
------------
Install as usual. OpenPGP.js v5.0.1 is shipped within the module. See disclaimer
below.

OPENPGP.JS
----------
There is a copy of minified openpgp.js in the module, at js/openpgp.min.js. It
is used to encrypt and decrypt content. The version of openpgp.js is 5.0.1. The
library is licensed under the LGPL-3.0. Source code available at
https://openpgpjs.org/. The minified version is available at
https://unpkg.com/openpgp@5.0.1/dist/openpgp.min.js.

FUTURE ROADMAP
--------------
Text area field encryption and decryption.

Cryptographic signature and signature verification.

Multiple signatures per content with recursive encryption.

LEARN MORE ABOUT PROTECTED CONTENT
----------------------------------

[Protected Content, Secure open source day - Haarlem (2019)](https://youtu.be/rVWrkZPGj3s "Protected Content, Secure open source day - Haarlem (2019)")

[Protected Content: end-to-end PGP encryption for Drupal, Drupal Camp - Kyiv (2019)](https://youtu.be/Gx8uxEpi4Po " end-to-end PGP encryption for Drupal, Drupal Camp - Kyiv (2019)")

[Protected Content by Asymmetrical Client Side Encryption, Drupal Dev Days - Ghent (2022)](https://drupalcamp.be/en/drupal-dev-days-2020/session/protected-content-asymmetrical-client-side-encryption "Protected Content by Asymmetrical Client Side Encryption, Drupal Dev Days - Ghent (2022)")

[A pretty good content protection (Workshop), Drupal Con - Prague (2022)](https://events.drupal.org/prague2022/sessions/pretty-good-content-protection-workshop "A pretty good content protection (Workshop), Drupal Con - Prague (2022)")

SIMILAR PROJECT
---------------

[Client-Side File Crypto](https://www.drupal.org/project/client_side_file_crypto "Client-Side File Crypto")

MAINTAINERS
-----------
Rodrigo Panchiniak Fernandes - https://www.drupal.org/user/411448

Duarte Briz (duartebriz) - https://www.drupal.org/u/duartebriz

Reva Gomes (revagomes) - https://www.drupal.org/u/revagomes
